BluetoothDevice class

Constructors

BluetoothDevice({required String name, required String address})

Properties

address → String
final
connected ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConnected(bool value) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseDevices(List<String> deviceStrings) → List<BluetoothDevice>