MethodChannelEasyBluePrinter class

An implementation of EasyBluePrinterPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commitPrint() → Future<void>
override
configurePrinter(PaperConfig config) → Future<void>
override
connectToDevice(BluetoothDevice device) → Future<bool>
override
disconnectFromDevice() → Future<bool>
override
getPairedDevices() → Future<List<BluetoothDevice>>
override
isConnected() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printData({required String data, required FS fontSize, required TA textAlign, required bool bold}) → Future<bool>
override
printEmptyLine({required int callTimes}) → Future<void>
override
printImage({required Uint8List bytes, required TA textAlign}) → Future<bool>
override
requestBluetoothPermissions() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited