EasyBluePrinterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • EasyBluePrinterPlatform
Implementers

Constructors

EasyBluePrinterPlatform()
Constructs a EasyBluePrinterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commitPrint() → Future<void>
configurePrinter(PaperConfig config) → Future<void>
connectToDevice(BluetoothDevice device) → Future<bool>
disconnectFromDevice() → Future<bool>
getPairedDevices() → Future<List<BluetoothDevice>>
isConnected() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printData({required String data, required FS fontSize, required TA textAlign, required bool bold}) → Future<bool>
printEmptyLine({required int callTimes}) → Future<void>
printImage({required Uint8List bytes, required TA textAlign}) → Future<bool>
requestBluetoothPermissions() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ EasyBluePrinterPlatform
The default instance of EasyBluePrinterPlatform to use.
getter/setter pair