PaperConfig class
Constructors
- PaperConfig({required int widthPixels})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthPixels → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- roll58mm → const PaperConfig
- Bobina de 58mm — largura de 384 pixels (padrão mais comum)
- roll80mm → const PaperConfig
- Bobina de 80mm — largura de 576 pixels